@@ -1,3 +1,5 @@
+INITIAL_COMMIT = "Initial commit"
+
 COMMIT_DELIMITER = "--commit-delimiter--"
 
 FAILED = "Commit validation: failed!"
@@ -17,7 +19,7 @@ EMOJI_CROSS = ":cross_mark:"
 
 PATTERN = (
     r"(?s)"  # To explictly make . match new line
-    r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert|bump)"  # type
+    r"(build|ci|docs|feat|fix|perf|refactor|style|test|chore|revert|bump|enabler)"  # type
     r"(\(\S+\))?!?:"  # scope
     r"( [^\n\r]+)"  # subject
     r"((\n\n.*)|(\s*))?$"
